/*
 * Jalview - A Sequence Alignment Editor and Viewer (Version 2.8.2)
 * Copyright (C) 2014 The Jalview Authors
 * 
 * This file is part of Jalview.
 * 
 * Jalview is free software: you can redistribute it and/or
 * modify it under the terms of the GNU General Public License 
 * as published by the Free Software Foundation, either version 3
 * of the License, or (at your option) any later version.
 *  
 * Jalview is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty 
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
 * PURPOSE.  See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Jalview.  If not, see <http://www.gnu.org/licenses/>.
 * The Jalview Authors are detailed in the 'AUTHORS' file.
 */
package jalview.ws;

import static org.junit.Assert.*;
import jalview.datamodel.AlignmentI;
import jalview.datamodel.SequenceI;
import jalview.ws.seqfetcher.DbSourceProxy;

import java.util.List;

import org.junit.Before;
import org.junit.Test;

public class PDBSequenceFetcherTest
{

  SequenceFetcher sf;

  @Before
  public void setUp() throws Exception
  {
    sf = new SequenceFetcher(false);
  }

  @Test
  public void testPdbPerChainRetrieve() throws Exception
  {
    List<DbSourceProxy> sps = sf.getSourceProxy("PDB");
    AlignmentI response = sps.get(0).getSequenceRecords("1QIPA");
    assertTrue(response != null);
    assertTrue(response.getHeight() == 1);
  }

  @Test
  public void testRnaSeqRetrieve() throws Exception
  {
    List<DbSourceProxy> sps = sf.getSourceProxy("PDB");
    AlignmentI response = sps.get(0).getSequenceRecords("2GIS");
    assertTrue(response != null);
    assertTrue(response.getHeight() == 1);
    for (SequenceI sq : response.getSequences())
    {
      assertTrue("No annotation transfered to sequence.",
              sq.getAnnotation().length > 0);
      assertTrue("No PDBEntry on sequence.", sq.getPDBId().size() > 0);
      assertTrue("No RNA annotation on sequence.", sq.getRNA() != null);
    }
  }

}
